@@ -3,7 +3,6 @@
 
 use crate::packet::{self, send_to, Packets, PacketsRecycler, PACKETS_PER_BATCH};
 use crate::recvmmsg::NUM_RCVMMSGS;
-use solana_measure::thread_mem_usage;
 use solana_sdk::timing::{duration_as_ms, timestamp};
 use std::net::UdpSocket;
 use std::sync::atomic::{AtomicBool, Ordering};
@@ -43,10 +42,7 @@ fn recv_loop(
     let mut now = Instant::now();
     let mut num_max_received = 0; // Number of times maximum packets were received
     loop {
-        let (mut msgs, should_send) =
-            Packets::new_with_recycler(recycler.clone(), PACKETS_PER_BATCH)
-                .map(|allocated| (allocated, true))
-                .unwrap_or((Packets::with_capacity(PACKETS_PER_BATCH), false));
+        let mut msgs = Packets::new_with_recycler(recycler.clone(), PACKETS_PER_BATCH, name);
         loop {
             // Check for exit signal, even if socket is busy
             // (for instance the leader transaction socket)
@@ -59,7 +55,7 @@ fn recv_loop(
                 }
                 recv_count += len;
                 call_count += 1;
-                if len > 0 && should_send {
+                if len > 0 {
                     channel.send(msgs)?;
                 }
                 break;
@@ -97,7 +93,6 @@ pub fn receiver(
     Builder::new()
         .name("solana-receiver".to_string())
         .spawn(move || {
-            thread_mem_usage::datapoint(name);
             let _ = recv_loop(
                 &sock,
                 exit,
@@ -144,7 +139,6 @@ pub fn responder(name: &'static str, sock: Arc<UdpSocket>, r: PacketReceiver) ->
             let mut last_error = None;
             let mut last_print = 0;
             loop {
-                thread_mem_usage::datapoint(name);
                 if let Err(e) = recv_send(&sock, &r) {
                     match e {
                         StreamerError::RecvTimeoutError(RecvTimeoutError::Disconnected) => break,
@@ -214,7 +208,7 @@ mod test {
             Arc::new(read),
             &exit,
             s_reader,
-            Recycler::new_without_limit(""),
+            Recycler::default(),
             "test",
             1,
         );
